@@ -9,3 +9,9 @@ stock_us = su
 
 from hawkdata.bond import cbond as cb
 cbond = cb
+
+from hawkdata.macro import china_gdp as cgdp
+china_gdp = cgdp
+
+from hawkdata.macro import china_cpi as ccpi
+china_cpi = ccpi
