@@ -74,7 +74,8 @@ class WebCrawlerBase:
            wait_random_min=1000,
            wait_random_max=3000)
     def _crawl(self, url, method='GET',
-              headers={}, params={}, data={}, timeout=5):
+              headers={}, params={}, data={}, timeout=5, ssl_verify=True,
+               cookies_dict={}):
 
         m = method.lower()
         if m == 'get':
@@ -92,6 +93,6 @@ class WebCrawlerBase:
         headers['X-Forwarded-For'] = self._get_random_ipv4_address()
 
         resp = func_request(url, headers=headers, params=params, data=data,
-                            timeout=timeout)
+                            timeout=timeout, verify=ssl_verify)
 
         return resp
